From 0223030d278ac74dc3cc95f0fff32034a40d903e Mon Sep 17 00:00:00 2001
From: Alvaro Herrera <alvherre@alvh.no-ip.org>
Date: Thu, 28 Nov 2019 19:35:43 -0300
Subject: [PATCH v7 09/13] pgindent

---
 src/backend/utils/adt/multirangetypes.c | 14 +++++++-------
 src/backend/utils/fmgr/funcapi.c        | 12 ++++++------
 src/bin/pg_dump/pg_dump.c               | 11 ++++++-----
 3 files changed, 19 insertions(+), 18 deletions(-)

diff --git a/src/backend/utils/adt/multirangetypes.c b/src/backend/utils/adt/multirangetypes.c
index b8ff39077c..f4dec1bbc9 100644
--- a/src/backend/utils/adt/multirangetypes.c
+++ b/src/backend/utils/adt/multirangetypes.c
@@ -330,13 +330,13 @@ multirange_recv(PG_FUNCTION_ARGS)
 Datum
 multirange_send(PG_FUNCTION_ARGS)
 {
-	MultirangeType	   *multirange = PG_GETARG_MULTIRANGE_P(0);
-	Oid					mltrngtypoid = MultirangeTypeGetOid(multirange);
-	StringInfo			buf = makeStringInfo();
-	RangeType		  **ranges;
-	int32				range_count;
-	int32				i;
-	MultirangeIOData	*cache;
+	MultirangeType *multirange = PG_GETARG_MULTIRANGE_P(0);
+	Oid			mltrngtypoid = MultirangeTypeGetOid(multirange);
+	StringInfo	buf = makeStringInfo();
+	RangeType **ranges;
+	int32		range_count;
+	int32		i;
+	MultirangeIOData *cache;
 
 	cache = get_multirange_io_data(fcinfo, mltrngtypoid, IOFunc_send);
 
diff --git a/src/backend/utils/fmgr/funcapi.c b/src/backend/utils/fmgr/funcapi.c
index 25623461bb..808a0e2ca7 100644
--- a/src/backend/utils/fmgr/funcapi.c
+++ b/src/backend/utils/fmgr/funcapi.c
@@ -630,8 +630,8 @@ resolve_polymorphic_tupdesc(TupleDesc tupdesc, oidvector *declared_args,
 	{
 		if (OidIsValid(anymultirange_type))
 		{
-			Oid		rngtype;
-			Oid		subtype;
+			Oid			rngtype;
+			Oid			subtype;
 
 			rngtype = resolve_generic_type(ANYRANGEOID,
 										   anymultirange_type,
@@ -665,9 +665,9 @@ resolve_polymorphic_tupdesc(TupleDesc tupdesc, oidvector *declared_args,
 	{
 		if (OidIsValid(anyrange_type))
 		{
-			Oid		subtype;
-			Oid		mltrngtype;
-			Oid		rngtype;
+			Oid			subtype;
+			Oid			mltrngtype;
+			Oid			rngtype;
 
 			subtype = resolve_generic_type(ANYELEMENTOID,
 										   anyrange_type,
@@ -911,7 +911,7 @@ resolve_polymorphic_argtypes(int numargs, Oid *argtypes, char *argmodes,
 		{
 			Oid			rngtype;
 			Oid			subtype;
-			
+
 			rngtype = resolve_generic_type(ANYRANGEOID,
 										   anymultirange_type,
 										   ANYMULTIRANGEOID);
diff --git a/src/bin/pg_dump/pg_dump.c b/src/bin/pg_dump/pg_dump.c
index 4a0a03d50c..8272a0451b 100644
--- a/src/bin/pg_dump/pg_dump.c
+++ b/src/bin/pg_dump/pg_dump.c
@@ -4276,15 +4276,16 @@ dumpSubscription(Archive *fout, SubscriptionInfo *subinfo)
 	free(qsubname);
 }
 
-static Oid get_next_possible_free_pg_type_oid(Archive *fout, PQExpBuffer upgrade_query)
+static Oid
+get_next_possible_free_pg_type_oid(Archive *fout, PQExpBuffer upgrade_query)
 {
 	/*
 	 * If the old version didn't assign an array type, but the new version
-	 * does, we must select an unused type OID to assign.  This currently
-	 * only happens for domains, when upgrading pre-v11 to v11 and up.
+	 * does, we must select an unused type OID to assign.  This currently only
+	 * happens for domains, when upgrading pre-v11 to v11 and up.
 	 *
-	 * Note: local state here is kind of ugly, but we must have some,
-	 * since we mustn't choose the same unused OID more than once.
+	 * Note: local state here is kind of ugly, but we must have some, since we
+	 * mustn't choose the same unused OID more than once.
 	 */
 	static Oid	next_possible_free_oid = FirstNormalObjectId;
 	PGresult   *res;
-- 
2.20.1

